powered by
Download a single file from NITRC
download_nitrc_file(file_path, destfile = NULL, prefix = NULL, verbose = FALSE, error = FALSE)
Path to the file to be dowloaded
Destination filename
Prefix the file name with this (prevents overwritting of same name files in case function is used to download multiple scan types at once)
Should progress be added to download?
Should function error if download failed?
Display path to the downloaded file
# NOT RUN { ## file_path is retrieved using the get_scan_resources() function # } # NOT RUN { r <- get_scan_resources('NITRC_IR_E10453') # } # NOT RUN { download_nitrc_file(r$URI[1]) # }
Run the code above in your browser using DataLab